@@ -505,7 +505,7 @@ def graph_features(DiG,df):
     output = merge_dataframes(output, df_nodes_self_loop_iteration)
     return output
 
-def user_timeline_extraction (node_list, consumerKey, consumerSecret,accessToken,accessTokenSecret, iter_tw,save_by, fichero):
+def user_timeline_extraction (node_list, consumerKey, consumerSecret,accessToken,accessTokenSecret, iter_tw,save_by, ruta_fichero, nombre_fichero):
     # get_user Returns the 20 most recent statuses posted from the authenticating user or the user specified. 
     profile_iter = save_by
     k=0
@@ -575,17 +575,17 @@ def user_timeline_extraction (node_list, consumerKey, consumerSecret,accessToken
                               "favourites_count": "favorites_count",
                               "full_text": "text"})
         df2 = metadata_extraction(df)
-        if path.exists("/content/"+ fichero):
-          df2.to_csv(fichero,mode="a", index=False, header=False)
+        if path.exists(ruta_fichero + nombre_fichero):
+          df2.to_csv(nombre_fichero,mode="a", index=False, header=False)
         else:
-          df2.to_csv(fichero,index=False)         
+          df2.to_csv(nombre_fichero,index=False)         
         if len(list_users_noInfo) !=0:
           nodes = pd.DataFrame()
           nodes["nodos"] = list_users_noInfo
-          if path.exists("/content/node_without_"+fichero):
-            nodes.to_csv("node_without_"+ fichero, mode ="a",index=False, header=False)          
+          if path.exists(ruta_fichero+"node_without_"+nombre_fichero):
+            nodes.to_csv("node_without_"+ nombre_fichero, mode ="a",index=False, header=False)          
           else:
-             nodes.to_csv("node_without_"+ fichero, index=False)
+             nodes.to_csv("node_without_"+ nombre_fichero, index=False)
         k = k+profile_iter        
         if ultima ==1:          
           ultima =2
@@ -1093,12 +1093,12 @@ def NLP_analysis(data, keyword_corpus, hashtag_corpus):
       
     return data,tweets_df
 	
-def more_tweets_required(df,df_graph_features,consumerKey,consumerSecret,accessToken,accessTokenSecret,n_groups,save_by):
+def more_tweets_required(df,df_graph_features,consumerKey,consumerSecret,accessToken,accessTokenSecret,n_groups,save_by,ruta_fichero,nombre_fichero):
 	df_evaluate = df[(df["evaluate_NLP"] !="No") & (df["evaluate_NLP"] !="More Data")]
 	node_list_moreData = list(df[df["evaluate_NLP"]=="More Data"]["screen_name"])
 	if len(node_list_moreData) >0:
-		df_metadata_moreData, list_more_Data_noData = user_timeline_extraction(node_list_moreData,consumerKey,consumerSecret,accessToken,accessTokenSecret,n_groups,save_by,"fichero_guardar_noData.csv")
-		df_metadata_moreData = pd.read_csv("/content/"+"fichero_guardar_noData.csv")
+		df_metadata_moreData, list_more_Data_noData = user_timeline_extraction(node_list_moreData,consumerKey,consumerSecret,accessToken,accessTokenSecret,n_groups,save_by,ruta_fichero, nombre_fichero)
+		df_metadata_moreData = pd.read_csv(ruta_fichero + nombre_fichero)
 		df_metadata_moreData = text_to_list_features_conversor(df_metadata_moreData)
 		df_metadata_moreData = advanced_features(df_metadata_moreData)
 		df_metadata_moreData = merge_dataframes(df_metadata_moreData,df_graph_features)
@@ -1128,7 +1128,7 @@ def text_to_list_features_conversor (data):
         for i in range(len(text_days)):
             #print(i)
             tweet_date_day = tweet_date_days[i].replace("), ",")??").strip("[]").split("??")
-            text_tweets_day = data["text_tweets_days_list"].iloc[index][i].replace("', '","??").strip("[]'").split("??")
+            text_tweets_day = data["text_tweets_days_list"].iloc[index][i].replace("', '","¿¿??").strip("[]'").split("¿¿??")
             if len(RT_days[i])==1:
                  RT_day = list(RT_days[i])
             else:
